@@ -107,16 +107,17 @@ def mock_vcf_df_single_sample_annotations() -> pd.DataFrame:
     return pd.DataFrame([
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-         'c.-856C>A', pd.NA],
+         'c.-856C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-         'c.497C>A', 'p.Ala166Glu'],
+         'c.497C>A', 'p.Ala166Glu', '497/1359'],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-         'c.-1941C>A', pd.NA]
+         'c.-1941C>A', pd.NA, pd.NA]
     ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
                 'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
                 'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
                 ])
 
 
@@ -125,16 +126,17 @@ def mock_vcf_df_single_sample_annotations_some_na_values() -> pd.DataFrame:
     return pd.DataFrame([
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-         'c.-856C>A', pd.NA],
+         'c.-856C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', pd.NA,
-         'c.497C>A', 'p.Ala166Glu'],
+         'c.497C>A', 'p.Ala166Glu', '497/1359'],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-         'c.-1941C>A', pd.NA]
+         'c.-1941C>A', pd.NA, pd.NA]
     ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
                 'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
                 'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
                 ])
 
 
@@ -143,25 +145,70 @@ def mock_vcf_df_multiple_sample_annotations() -> pd.DataFrame:
     return pd.DataFrame([
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-         'c.-856C>A', pd.NA],
+         'c.-856C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-         'c.497C>A', 'p.Ala166Glu'],
+         'c.497C>A', 'p.Ala166Glu', '497/1359'],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-         'c.-1941C>A', pd.NA],
+         'c.-1941C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T',
          'T', 'missense_variant', 'MODERATE', 'SEHA_RS01460', 'SEHA_RS01460', 'transcript',
-         'protein_coding', 'c.602C>T', 'p.Thr201Met'],
+         'protein_coding', 'c.602C>T', 'p.Thr201Met', '602/927'],
         ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T',
          'T', 'upstream_gene_variant', 'MODIFIER', 'SEHA_RS01455', 'SEHA_RS01455',
-         'transcript', 'protein_coding', 'c.-2172G>A', pd.NA],
+         'transcript', 'protein_coding', 'c.-2172G>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T',
          'T', 'upstream_gene_variant', 'MODIFIER', 'SEHA_RS01455', 'SEHA_RS01455',
-         'transcript', 'protein_coding', 'c.-710G>A', pd.NA],
+         'transcript', 'protein_coding', 'c.-710G>A', pd.NA, pd.NA],
     ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
                 'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
                 'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
+                ])
+
+
+@pytest.fixture
+def mock_vcf_df_single_sample_annotations_sars_cov_2() -> pd.DataFrame:
+    return pd.DataFrame([
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.3683A>G', 'p.D1228G', '3683/21291'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.3683A>G', 'p.D1228G', '3683/13218'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.1229A>G', 'p.D410G', '1229/5835'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.1229A>G', 'p.D410G', '1229/5835'],
+    ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
+                'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
+                'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
+                ])
+
+
+@pytest.fixture
+def mock_vcf_df_single_sample_annotations_rv_sars_cov_2() -> pd.DataFrame:
+    return pd.DataFrame([
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.1229A>G', 'p.D410G', '1229/5835'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.1229A>G', 'p.D410G', '1229/5835'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.3683A>G', 'p.D1228G', '3683/13218'],
+        ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+         'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+         'c.3683A>G', 'p.D1228G', '3683/21291'],
+    ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
+                'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
+                'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
                 ])
 
 
@@ -170,17 +217,18 @@ def mock_vcf_df_multiple_sample_one_empty() -> pd.DataFrame:
     return pd.DataFrame([
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-         'c.-856C>A', pd.NA],
+         'c.-856C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-         'c.497C>A', 'p.Ala166Glu'],
+         'c.497C>A', 'p.Ala166Glu', '497/1359'],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-         'c.-1941C>A', pd.NA],
-        ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T'] + [pd.NA] * 9,
+         'c.-1941C>A', pd.NA, pd.NA],
+        ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T'] + [pd.NA] * 10,
     ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
                 'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-                'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'
+                'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length',
                 ])
 
 
@@ -189,22 +237,23 @@ def mock_vcf_df_multiple_sample_one_invalid() -> pd.DataFrame:
     return pd.DataFrame([
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-         'c.-856C>A', pd.NA],
+         'c.-856C>A', pd.NA, pd.NA],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-         'c.497C>A', 'p.Ala166Glu'],
+         'c.497C>A', 'p.Ala166Glu', '497/1359'],
         ['SampleA', 'NC_011083', 140658, 'C', 'A', 'snp', 'SampleA.vcf', 'NC_011083:140658:C:A',
          'A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-         'c.-1941C>A', pd.NA],
+         'c.-1941C>A', pd.NA, pd.NA],
 
         # This one is invalid because snpeff 'Allele' refers to some other variant (indicating it's a compound variant)
         # I want to ignore all compound variants because it would be very difficult to index them in my software.
         ['SampleA', 'NC_011083', 203200, 'C', 'T', 'snp', 'SampleA.vcf', 'NC_011083:203200:C:T',
          'T:123456_A>T', 'missense_variant', 'MODERATE', 'SEHA_RS01460', 'SEHA_RS01460', 'transcript',
-         'protein_coding', 'c.602C>T', 'p.Thr201Met'],
+         'protein_coding', 'c.602C>T', 'p.Thr201Met', '602/927'],
     ], columns=['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
                 'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
                 'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p',
+                'ANN.cDNA.pos / cDNA.length'
                 ])
 
 
@@ -274,12 +323,13 @@ def test_parse_annotation_entries_single(vcf_snpeff_annotation_parser: VcfSnpEff
                                                                            vcf_df=mock_vcf_df_with_ann_single)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 1 == len(ann_entries_df)
     assert [0] == list(ann_entries_df.index)
     assert ['A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-            'c.497C>A', 'p.Ala166Glu', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
+            'c.497C>A', 'p.Ala166Glu', '497/1359', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
 
 
 def test_parse_annotation_entries_multiple_entries_single_sample(
@@ -290,17 +340,18 @@ def test_parse_annotation_entries_multiple_entries_single_sample(
                                                                            vcf_df=mock_vcf_df_with_ann_multiple_entries_single_sample)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 3 == len(ann_entries_df)
     ann_entries_df = ann_entries_df.sort_values(['original_index', 'ANN.Gene_ID'])
     assert [0, 0, 0] == list(ann_entries_df.index)
     assert ['A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-            'c.497C>A', 'p.Ala166Glu', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
+            'c.497C>A', 'p.Ala166Glu', '497/1359', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-            'c.-856C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
+            'c.-856C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-            'c.-1941C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
+            'c.-1941C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
 
 
 def test_parse_annotation_entries_multiple_entries_multiple_samples(
@@ -311,24 +362,25 @@ def test_parse_annotation_entries_multiple_entries_multiple_samples(
                                                                            vcf_df=mock_vcf_df_with_ann_multiple_entries_multiple_samples)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 6 == len(ann_entries_df)
     ann_entries_df = ann_entries_df.sort_values(['original_index', 'ANN.Gene_ID'])
     assert [0, 0, 0, 1, 1, 1] == list(ann_entries_df.index)
     assert ['A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-            'c.497C>A', 'p.Ala166Glu', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
+            'c.497C>A', 'p.Ala166Glu', '497/1359', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-            'c.-856C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
+            'c.-856C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-            'c.-1941C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
+            'c.-1941C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
 
     assert ['T', 'upstream_gene_variant', 'MODIFIER', 'SEHA_RS01445', 'SEHA_RS01445', 'transcript', 'protein_coding',
-            'c.-2172G>A', pd.NA, 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[3])
+            'c.-2172G>A', pd.NA, pd.NA, 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[3])
     assert ['T', 'upstream_gene_variant', 'MODIFIER', 'can', 'SEHA_RS01455', 'transcript', 'protein_coding',
-            'c.-710G>A', pd.NA, 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[4])
+            'c.-710G>A', pd.NA, pd.NA, 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[4])
     assert ['T', 'missense_variant', 'MODERATE', 'SEHA_RS01460', 'SEHA_RS01460', 'transcript', 'protein_coding',
-            'c.602C>T', 'p.Thr201Met', 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[5])
+            'c.602C>T', 'p.Thr201Met', '602/927', 'NC_011083:203200:C:T'] == list(ann_entries_df.iloc[5])
 
 
 def test_parse_annotation_entries_no_annotation_single_sample(vcf_snpeff_annotation_parser: VcfSnpEffAnnotationParser,
@@ -337,7 +389,8 @@ def test_parse_annotation_entries_no_annotation_single_sample(vcf_snpeff_annotat
                                                                            vcf_df=mock_vcf_df_without_ann_single)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 1 == len(ann_entries_df)
     assert [0] == list(ann_entries_df.index)
@@ -351,7 +404,8 @@ def test_parse_annotation_entries_no_annotation_multiple_sample(vcf_snpeff_annot
                                                                            vcf_df=mock_vcf_df_without_ann_multiple)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 2 == len(ann_entries_df)
     assert [0, 1] == list(ann_entries_df.index)
@@ -370,17 +424,18 @@ def test_parse_annotation_entries_some_with_some_without_annotations(
                                                                            vcf_df=mock_vcf_df_with_and_without_ann)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 4 == len(ann_entries_df)
     ann_entries_df = ann_entries_df.sort_values(['original_index', 'ANN.Gene_ID'])
     assert [0, 0, 0, 1] == list(ann_entries_df.index)
     assert ['A', 'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
-            'c.497C>A', 'p.Ala166Glu', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
+            'c.497C>A', 'p.Ala166Glu', '497/1359', 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[0])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'mraY', 'SEHA_RS01185', 'transcript', 'protein_coding',
-            'c.-856C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
+            'c.-856C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[1])
     assert ['A', 'upstream_gene_variant', 'MODIFIER', 'murD', 'SEHA_RS01190', 'transcript', 'protein_coding',
-            'c.-1941C>A', pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
+            'c.-1941C>A', pd.NA, pd.NA, 'NC_011083:140658:C:A'] == list(ann_entries_df.iloc[2])
 
     assert {True} == set(ann_entries_df.drop('VARIANT_ID', axis='columns').iloc[3].isna())
     assert 'NC_011083:203200:C:T' == ann_entries_df['VARIANT_ID'].iloc[3]
@@ -392,7 +447,8 @@ def test_parse_annotation_entries_empty(vcf_snpeff_annotation_parser: VcfSnpEffA
                                                                            vcf_df=mock_vcf_df_empty)
 
     assert ['ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
-            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'VARIANT_ID'] == list(
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p', 'ANN.cDNA.pos / cDNA.length',
+            'VARIANT_ID'] == list(
         ann_entries_df.columns)
     assert 0 == len(ann_entries_df)
 
@@ -400,7 +456,6 @@ def test_parse_annotation_entries_empty(vcf_snpeff_annotation_parser: VcfSnpEffA
 def test_select_variant_annotations_single_sample(vcf_snpeff_annotation_parser: VcfSnpEffAnnotationParser,
                                                   mock_vcf_df_single_sample_annotations: pd.DataFrame):
     ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(mock_vcf_df_single_sample_annotations)
-    assert mock_vcf_df_single_sample_annotations.columns.tolist() == ann_entries_df.columns.tolist()
     assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
             'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
             'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
@@ -415,7 +470,6 @@ def test_select_variant_annotations_some_na_values(vcf_snpeff_annotation_parser:
                                                    mock_vcf_df_single_sample_annotations_some_na_values: pd.DataFrame):
     ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(
         mock_vcf_df_single_sample_annotations_some_na_values)
-    assert mock_vcf_df_single_sample_annotations_some_na_values.columns.tolist() == ann_entries_df.columns.tolist()
     assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
             'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
             'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
@@ -426,10 +480,37 @@ def test_select_variant_annotations_some_na_values(vcf_snpeff_annotation_parser:
             'c.497C>A', 'p.Ala166Glu'] == list(ann_entries_df.iloc[0].fillna('NA'))
 
 
+def test_select_variant_annotations_single_sample_sars_cov_2(vcf_snpeff_annotation_parser: VcfSnpEffAnnotationParser,
+                                                             mock_vcf_df_single_sample_annotations_sars_cov_2: pd.DataFrame):
+    ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(
+        mock_vcf_df_single_sample_annotations_sars_cov_2)
+    assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
+            'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
+        ann_entries_df.columns)
+    assert 1 == len(ann_entries_df)
+    assert ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+            'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+            'c.3683A>G', 'p.D1228G'] == list(ann_entries_df.iloc[0])
+
+
+def test_select_variant_annotations_rv_single_sample_sars_cov_2(vcf_snpeff_annotation_parser: VcfSnpEffAnnotationParser,
+                                                                mock_vcf_df_single_sample_annotations_rv_sars_cov_2: pd.DataFrame):
+    ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(
+        mock_vcf_df_single_sample_annotations_rv_sars_cov_2)
+    assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
+            'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
+            'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
+        ann_entries_df.columns)
+    assert 1 == len(ann_entries_df)
+    assert ['SampleA', 'NC_045512.2', 3948, 'A', 'G', 'SNP', 'SampleA.vcf', 'NC_045512.2:3948:A:G',
+            'G', 'missense_variant', 'MODERATE', 'ORF1ab', 'GU280_gp01', 'transcript', 'protein_coding',
+            'c.3683A>G', 'p.D1228G'] == list(ann_entries_df.iloc[0])
+
+
 def test_select_variant_annotations_multiple_sample(vcf_snpeff_annotation_parser: VcfSnpEffAnnotationParser,
                                                     mock_vcf_df_multiple_sample_annotations: pd.DataFrame):
     ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(mock_vcf_df_multiple_sample_annotations)
-    assert mock_vcf_df_multiple_sample_annotations.columns.tolist() == ann_entries_df.columns.tolist()
     assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
             'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
             'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
@@ -449,7 +530,6 @@ def test_select_variant_annotations_one_no_annotation(vcf_snpeff_annotation_pars
                           'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p']
 
     ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(mock_vcf_df_multiple_sample_one_empty)
-    assert mock_vcf_df_multiple_sample_one_empty.columns.tolist() == ann_entries_df.columns.tolist()
     assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
             'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
             'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
@@ -469,7 +549,6 @@ def test_select_variant_annotations_one_invalid_annotation(vcf_snpeff_annotation
                           'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p']
 
     ann_entries_df = vcf_snpeff_annotation_parser.select_variant_annotations(mock_vcf_df_multiple_sample_one_invalid)
-    assert mock_vcf_df_multiple_sample_one_invalid.columns.tolist() == ann_entries_df.columns.tolist()
     assert ['SAMPLE', 'CHROM', 'POS', 'REF', 'ALT', 'TYPE', 'FILE', 'VARIANT_ID',
             'ANN.Allele', 'ANN.Annotation', 'ANN.Annotation_Impact', 'ANN.Gene_Name', 'ANN.Gene_ID',
             'ANN.Feature_Type', 'ANN.Transcript_BioType', 'ANN.HGVS.c', 'ANN.HGVS.p'] == list(
